@@ -9,7 +9,7 @@ use std::time::Duration;
 use async_trait::async_trait;
 use vm_memory::ByteValued;
 
-use super::{MetricsHook, Server, ServerUtil, SrvContext};
+use super::{MetricsHook, Server, ServerUtil, SrvContext, BUFFER_HEADER_SIZE};
 use crate::abi::fuse_abi::*;
 use crate::api::filesystem::{
     AsyncFileSystem, AsyncZeroCopyReader, AsyncZeroCopyWriter, ZeroCopyReader, ZeroCopyWriter,
@@ -121,7 +121,9 @@ impl<F: AsyncFileSystem<D> + Sync, D: AsyncDrive> Server<F, D> {
     ) -> Result<usize> {
         let in_header = r.read_obj().map_err(Error::DecodeMessage)?;
         let mut ctx = SrvContext::<F, D, S>::with_drive(in_header, r, w, drive);
-        if ctx.in_header.len > MAX_BUFFER_SIZE || ctx.w.available_bytes() < size_of::<OutHeader>() {
+        if ctx.in_header.len > (MAX_BUFFER_SIZE + BUFFER_HEADER_SIZE)
+            || ctx.w.available_bytes() < size_of::<OutHeader>()
+        {
             return ctx
                 .async_do_reply_error(io::Error::from_raw_os_error(libc::ENOMEM), true)
                 .await;
@@ -133,7 +135,7 @@ impl<F: AsyncFileSystem<D> + Sync, D: AsyncDrive> Server<F, D> {
             Opcode::from(in_header.opcode),
             in_header
         );
-        hook.map_or((), |h| h.collect(&in_header));
+        hook.map_or((), |h| h.collect(in_header));
 
         let res = match in_header.opcode {
             x if x == Opcode::Lookup as u32 => self.async_lookup(ctx).await,
@@ -215,7 +217,7 @@ impl<F: AsyncFileSystem<D> + Sync, D: AsyncDrive> Server<F, D> {
         let name = bytes_to_cstr(buf.as_ref())?;
         let result = self
             .fs
-            .async_lookup(ctx.context(), ctx.nodeid(), &name)
+            .async_lookup(ctx.context(), ctx.nodeid(), name)
             .await;
 
         match result {
