@@ -29,7 +29,7 @@ use std::time::Duration;
 use arc_swap::ArcSwap;
 
 use super::pseudo_fs::PseudoFs;
-use crate::abi::linux_abi::*;
+use crate::abi::fuse_abi::*;
 use crate::api::filesystem::*;
 use crate::async_util::{AsyncDrive, AsyncDriver};
 
@@ -226,6 +226,12 @@ pub struct VfsOptions {
     pub out_opts: FsOptions,
 }
 
+impl VfsOptions {
+    fn new() -> Self {
+        VfsOptions::default()
+    }
+}
+
 impl Default for VfsOptions {
     fn default() -> Self {
         VfsOptions {
@@ -239,13 +245,16 @@ impl Default for VfsOptions {
                 | FsOptions::PARALLEL_DIROPS
                 | FsOptions::BIG_WRITES
                 | FsOptions::ASYNC_DIO
+                | FsOptions::AUTO_INVAL_DATA
                 | FsOptions::HAS_IOCTL_DIR
                 | FsOptions::WRITEBACK_CACHE
                 | FsOptions::ZERO_MESSAGE_OPEN
+                | FsOptions::MAX_PAGES
                 | FsOptions::ATOMIC_O_TRUNC
                 | FsOptions::CACHE_SYMLINKS
                 | FsOptions::DO_READDIRPLUS
                 | FsOptions::READDIRPLUS_AUTO
+                | FsOptions::EXPLICIT_INVAL_DATA
                 | FsOptions::ZERO_MESSAGE_OPENDIR
                 | FsOptions::HANDLE_KILLPRIV_V2
                 | FsOptions::PERFILE_DAX,
@@ -269,7 +278,7 @@ pub struct Vfs<D: AsyncDrive = AsyncDriver> {
 
 impl<D: AsyncDrive> Default for Vfs<D> {
     fn default() -> Self {
-        Self::new(VfsOptions::default())
+        Self::new(VfsOptions::new())
     }
 }
 
@@ -294,6 +303,11 @@ impl<D: AsyncDrive> Vfs<D> {
         self.initialized.load(Ordering::Acquire)
     }
 
+    /// Get a snapshot of the current vfs options.
+    pub fn options(&self) -> VfsOptions {
+        *self.opts.load_full()
+    }
+
     fn insert_mount_locked(
         &self,
         fs: BackFileSystem<D>,
@@ -372,7 +386,11 @@ impl<D: AsyncDrive> Vfs<D> {
             .get(&inode)
             .map(Arc::clone)
             .map(|x| {
-                self.root.evict_inode(inode);
+                // Do not remove pseudofs inode. We keep all pseudofs inode so that
+                // 1. they can be reused later on
+                // 2. during live upgrade, it is easier reconstruct pseudofs inodes since
+                //    we do not have to track pseudofs deletions
+                //self.root.evict_inode(inode);
                 mountpoints.remove(&inode);
                 self.mountpoints.store(Arc::new(mountpoints));
                 x.fs_idx
@@ -624,7 +642,7 @@ mod tests {
     #[cfg(feature = "async-io")]
     mod async_io {
         use super::*;
-        use crate::abi::linux_abi::{OpenOptions, SetattrValid};
+        use crate::abi::fuse_abi::{OpenOptions, SetattrValid};
         use async_trait::async_trait;
 
         #[allow(unused_variables)]
@@ -927,21 +945,8 @@ mod tests {
         let vfs = Vfs::<AsyncDriver>::default();
         assert_eq!(vfs.initialized(), false);
 
-        let out_opts = FsOptions::ASYNC_READ
-            | FsOptions::PARALLEL_DIROPS
-            | FsOptions::BIG_WRITES
-            | FsOptions::ASYNC_DIO
-            | FsOptions::HAS_IOCTL_DIR
-            | FsOptions::WRITEBACK_CACHE
-            | FsOptions::ZERO_MESSAGE_OPEN
-            | FsOptions::ATOMIC_O_TRUNC
-            | FsOptions::CACHE_SYMLINKS
-            | FsOptions::DO_READDIRPLUS
-            | FsOptions::READDIRPLUS_AUTO
-            | FsOptions::ZERO_MESSAGE_OPENDIR
-            | FsOptions::HANDLE_KILLPRIV_V2
-            | FsOptions::PERFILE_DAX;
         let opts = vfs.opts.load();
+        let out_opts = opts.out_opts;
 
         assert_eq!(opts.no_open, true);
         assert_eq!(opts.no_opendir, true);
@@ -949,7 +954,6 @@ mod tests {
         assert_eq!(opts.no_readdir, false);
         assert_eq!(opts.killpriv_v2, false);
         assert_eq!(opts.in_opts.is_empty(), true);
-        assert_eq!(opts.out_opts, out_opts);
 
         vfs.init(FsOptions::ASYNC_READ).unwrap();
         assert_eq!(vfs.initialized(), true);
